# aioble
[![Build Status](https://travis-ci.org/detectlabs/aioble.svg?branch=master)](https://travis-ci.org/detectlabs/aioble)

## Development Phases
#### Phase 1 (Central Role) - In Progress
#### Phase 2 (Peripheral Role) - Not Started 
#### Phase 3 (Beacon Role) - Not Started

## Install
##### Requires Python 3.6 for crossplatform support
```
python setup.py install
```

## Linux  
Supports Linux distributions with BlueZ >= 5.45
#### Note
You must call disconnect, even if a connection was not successful, in order to cleanup dbus related resources.
## Mac OS  
Supports macOS
## Windows  
Supports Windows 10, version 16299 (Fall Creators Update)
